@@ -1,17 +1,24 @@
 """Decoder for the MaxMind DB data section."""
 
+from __future__ import annotations
+
 import struct
-from typing import ClassVar, Union, cast
+from typing import TYPE_CHECKING, ClassVar, cast
 
 try:
     import mmap
 except ImportError:
     mmap = None  # type: ignore[assignment]
 
-
 from maxminddb.errors import InvalidDatabaseError
-from maxminddb.file import FileBuffer
-from maxminddb.types import Record
+
+if TYPE_CHECKING:
+    from collections.abc import Callable
+
+    from maxminddb.file import FileBuffer
+    from maxminddb.types import Record
+
+    DecoderFunc = Callable[["Decoder", int, int], tuple[Record, int]]
 
 
 class Decoder:
@@ -19,7 +26,7 @@ class Decoder:
 
     def __init__(
         self,
-        database_buffer: Union[FileBuffer, "mmap.mmap", bytes],
+        database_buffer: FileBuffer | mmap.mmap | bytes,
         pointer_base: int = 0,
         pointer_test: bool = False,  # noqa: FBT001, FBT002
     ) -> None:
@@ -114,7 +121,7 @@ class Decoder:
         new_offset = offset + size
         return self._buffer[offset:new_offset].decode("utf-8"), new_offset
 
-    _type_decoder: ClassVar = {
+    _type_decoder: ClassVar[dict[int, DecoderFunc]] = {
         1: _decode_pointer,
         2: _decode_utf8_string,
         3: _decode_double,
